
#ifndef _C11_ev528_
#define _C11_ev528_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1200_10804(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit528(void);
extern char *(*R10467[])();
extern long O8686[];

#ifdef __cplusplus
}
#endif

#endif
